<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Oath
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="hfeed site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'oath' ); ?></a>

	<header id="masthead" class="site-header" role="banner">
		<?php if ( has_nav_menu( 'contact' ) || has_nav_menu( 'social-header' ) ) : ?>
			<div class="secondary-header">
				<div class="wrapper">
					<?php if ( has_nav_menu( 'contact' ) ) : ?>
						<nav class="contact-navigation" role="navigation">
							<?php wp_nav_menu( array(
								'theme_location' => 'contact',
								'depth'          => 1,
								'menu_id'        => 'contact-menu' ) );
							?>
						</nav><!-- .contact-navigation -->
					<?php endif; ?>
					<?php if ( has_nav_menu( 'social-header' ) ) : ?>
						<nav class="social-navigation" role="navigation">
							<?php wp_nav_menu( array(
								'theme_location'  => 'social-header',
								'depth'           => 1,
								'link_before'     => '<span class="screen-reader-text">',
								'link_after'      => '</span>',
								'menu_id'         => 'social-menu', ) );
							?>
						</nav><!-- .social-navigation -->
					<?php endif; ?>
				</div>
			</div>
		<?php endif; ?>
		<div class="primary-header">
			<div class="site-branding">
				<?php if ( function_exists( 'the_custom_logo' ) && has_custom_logo() ) : ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div><!-- .site-logo -->
				<?php endif; ?>
				
				<div class="site-branding-text">
					<?php if ( is_front_page() && is_home() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php
					endif;
					
					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
					<?php
					endif; ?>
				</div><!-- .site-branding-text -->
			</div><!-- .site-branding -->

			<nav id="site-navigation" class="main-navigation" role="navigation">
				<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php esc_html_e( 'Menu', 'oath' ); ?></button>
				<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
			</nav><!-- #site-navigation -->
		</div><!-- .primary-header -->
	</header><!-- #masthead -->

	<div id="content" class="site-content">
